@@ -1,4 +1,7 @@
 package Grimlock;
+{
+  $Grimlock::VERSION = '0.032';
+}
 
 =head1 NAME
 
@@ -28,6 +31,17 @@ SO ME GRIMLOCK MAKE THIS BLOG SO I CAN WRITE ABOUT PETRO RABBITS, KICKING BUTT,
 
 ME GRIMLOCK KING!
 
+=head1 TODO
+
+ME GRIMLOCK WRITE BAD ASS SOFTWARE BUT NO HAVE TIME TO WRITE EVERYTHING AT ONCE.  THIS BLOG NEED:
+
+1. BETTER DESIGN.  DESIGN SUCK AND LOOK BAD.
+2. EDIT SCREENS.  WHOOPS FORGOT TO MAKE THOSE.
+3. SEARCH.  I GUESS USE SOMETHING LIKE LUCY FOR DEFAULT SEARCH, WHAT, ME LOOK LIKE GOOGLE TO YOU?
+4. WORKER PROCESS THINGY.  ME WANT PROCESS THINGS IN GOOD SOFTWARE DESIGN METHODOLOGY SO ME NO MAKE WEB APP DO LOTS OF WORK.
+5. ATTACHMENTS.  IMAGES OF SLUDGE GETTING BUTT KICKED BY DEVASTATOR MAKE GRIMLOCK LAUGH, ME WANT UPLOAD EVERYDAY.
+6. REMOVE ::NEXT STUFF FROM VIEW::TT.  NEXT IS DUMB. ME NO LIKE.
+
 =head1 LICENSE
 
 ME GRIMLOCK WANT SHARE BEAUTIFUL SOFTWARE ME WRITE WITH WORLD.  ME GRIMLOCK SAY THIS SOFTWARE RELEASE UNDER ARTISTIC LICENSE.
@@ -40,6 +54,7 @@ ME, GRIMLOCK!
 
 GRIMLOCK NO USE EMAIL, EMAIL BORING. EMAIL THIS GUY INSTEAD: L<mailto:dhoss@cpan.org>
 
+
 =head1 SEE ALSO
 
 L<http://www.imdb.com/title/tt0092106/>
